package com.aelitis.azureus.ui.swt.browser.listener.publish;

import java.io.File;
import java.net.URL;

public interface LocalHoster
{
	public URL hostFile(File f);
}
